@@ -1,7 +1,7 @@
 __project_name__ = 'upsies'
 __description__ = 'Media metadata aggregator'
 __homepage__ = 'https://upsies.readthedocs.io'
-__version__ = '2021.06.22'
+__version__ = '2021.07.06'
 __author__ = 'plotski'
 __author_email__ = 'plotski@example.org'
 
@@ -12,8 +12,8 @@ def application_setup(config):
 
     :param config: :class:`~.configfiles.ConfigFiles` instance
     """
-    from .utils import http
-    http.cache_directory = config['config']['main']['cache_directory']
+    from . import utils
+    utils.http.cache_directory = config['config']['main']['cache_directory']
 
 
 def application_shutdown(config):
@@ -22,9 +22,9 @@ def application_shutdown(config):
 
     :param config: :class:`~.configfiles.ConfigFiles` instance
     """
-    from .utils import fs, http
-    http.close()
-    fs.limit_directory_size(
+    from . import utils
+    utils.http.close()
+    utils.fs.limit_directory_size(
         path=config['config']['main']['cache_directory'],
         max_total_size=config['config']['main']['max_cache_size'],
     )
