@@ -419,7 +419,10 @@ class JobBase(abc.ABC):
                 self.exception(e)
             else:
                 if callback:
-                    callback(result)
+                    try:
+                        callback(result)
+                    except BaseException as e:
+                        self.exception(e)
                 return result
             finally:
                 if finish_when_done:
@@ -440,6 +443,11 @@ class JobBase(abc.ABC):
         self._tasks.append(wrapped)
         return wrapped
 
+    async def await_tasks(self):
+        """Block until all coroutines passed to :meth:`add_task` are done"""
+        for task in self._tasks:
+            await task
+
     def _write_cache(self):
         """
         Store recorded signals in :attr:`cache_file`
