@@ -409,20 +409,23 @@ class BbTrackerJobs(TrackerJobsBase):
 
     @cached_property
     def movie_container_job(self):
+        # Get file extension from largest file
+        files = sorted(fs.file_list(self.content_path), key=fs.file_size)
+        autodetected_extension = fs.file_extension(files[-1])
         return self.make_choice_job(
             name='movie-container',
             label='Container',
             condition=self.make_job_condition('movie_container_job', release.ReleaseType.movie),
-            autodetected=fs.file_extension(video.first_video(self.content_path)),
+            autodetected=autodetected_extension,
             autofinish=True,
             options=(
-                {'label': 'AVI', 'value': 'AVI', 'regex': re.compile(r'(?i:AVI)')},
-                {'label': 'MKV', 'value': 'MKV', 'regex': re.compile('(?i:MKV)')},
-                {'label': 'MP4', 'value': 'MP4', 'regex': re.compile(r'(?i:MP4)')},
-                {'label': 'TS', 'value': 'TS', 'regex': re.compile(r'(?i:TS)')},
-                {'label': 'VOB', 'value': 'VOB', 'regex': re.compile(r'(?i:VOB)')},
-                {'label': 'WMV', 'value': 'WMV', 'regex': re.compile(r'(?i:WMV)')},
-                {'label': 'm2ts', 'value': 'm2ts', 'regex': re.compile(r'(?i:m2ts)')},
+                {'label': 'AVI', 'value': 'AVI', 'regex': re.compile(r'^(?i:avi)$')},
+                {'label': 'MKV', 'value': 'MKV', 'regex': re.compile('^(?i:mkv)$')},
+                {'label': 'MP4', 'value': 'MP4', 'regex': re.compile(r'^(?i:mp4)$')},
+                {'label': 'TS', 'value': 'TS', 'regex': re.compile(r'^(?i:ts)$')},
+                {'label': 'VOB', 'value': 'VOB', 'regex': re.compile(r'^(?i:vob)$')},
+                {'label': 'WMV', 'value': 'WMV', 'regex': re.compile(r'^(?i:wmv)$')},
+                {'label': 'm2ts', 'value': 'm2ts', 'regex': re.compile(r'^(?i:m2ts|mts)$')},
             ),
         )
 
@@ -444,6 +447,7 @@ class BbTrackerJobs(TrackerJobsBase):
             label='Poster',
             condition=self.make_job_condition('movie_poster_job', release.ReleaseType.movie),
             worker=self.movie_get_poster_url,
+            catch=(errors.RequestError,),
             **self.common_job_args,
         )
 
@@ -547,6 +551,7 @@ class BbTrackerJobs(TrackerJobsBase):
             label='Poster',
             condition=self.make_job_condition('series_poster_job', release.ReleaseType.season, release.ReleaseType.episode),
             worker=self.series_get_poster_url,
+            catch=(errors.RequestError,),
             **self.common_job_args,
         )
 
@@ -1079,15 +1084,15 @@ class BbTrackerJobs(TrackerJobsBase):
         if self.is_movie_release or self.is_episode_release:
             runtime = video.duration(self.content_path)
         elif self.is_season_release:
-            # Return average runtime
-            filepaths = fs.file_list(
-                self.content_path,
-                extensions=constants.VIDEO_FILE_EXTENSIONS,
-            )
+            # Get all video files
+            filepaths = fs.file_list(self.content_path, extensions=constants.VIDEO_FILE_EXTENSIONS)
             if len(filepaths) >= 5:
-                # Ignore first and last episode as they are often longer
+                # Ignore first and last episode as they can be significantly longer
                 filepaths = filepaths[1:-1]
-            runtime = sum(video.duration(f) for f in filepaths) / len(filepaths)
+            # Get average from 3 episodes
+            filepaths = filepaths[:3]
+            durations = [video.duration(f) for f in filepaths]
+            runtime = sum(durations) / len(durations)
         else:
             return None
         return f'[b]Runtime[/b]: {timestamp.pretty(runtime)}'
@@ -1183,7 +1188,7 @@ class BbTrackerJobs(TrackerJobsBase):
         elif self.is_series_release:
             post_data = {
                 'submit': 'true',
-                'type': 'TV',
+                'type': 'Anime' if self.options['anime'] else 'TV',
                 'title': self.get_job_output(self.series_title_job, slice=0),
                 'tags': self.get_job_output(self.series_tags_job, slice=0),
                 'desc': self.get_job_output(self.series_description_job, slice=0),
