@@ -70,6 +70,7 @@ class BhdTrackerJobs(TrackerJobsBase):
             self.source_job,
             self.description_job,
             self.scene_check_job,
+            self.tags_job,
         )
 
     def make_job_condition(self, job_attr):
@@ -96,8 +97,8 @@ class BhdTrackerJobs(TrackerJobsBase):
             autodetected=self.guessed_release_name.type,
             autofinish=False,
             options=(
-                {'label': 'Movie', 'value': 1, 'match': self.is_movie_type},
-                {'label': 'TV', 'value': 2, 'match': self.is_series_type},
+                {'label': 'Movie', 'value': '1', 'match': self.is_movie_type},
+                {'label': 'TV', 'value': '2', 'match': self.is_series_type},
             ),
         )
 
@@ -166,7 +167,6 @@ class BhdTrackerJobs(TrackerJobsBase):
             name='source',
             label='Source',
             condition=self.make_job_condition('source_job'),
-            autofinish=False,
             options=(
                 {'label': 'Blu-ray', 'value': 'Blu-ray'},
                 {'label': 'HD-DVD', 'value': 'HD-DVD'},
@@ -191,9 +191,14 @@ class BhdTrackerJobs(TrackerJobsBase):
             _log.debug('Approved source: %r', approved_release_name.source)
             for label, is_match in self._autodetect_source_map.items():
                 if is_match(approved_release_name):
+                    # Focus autodetected choice
                     self.source_job.focused = label
+                    # Get value of autodetected choice
                     value = self.source_job.focused[1]
+                    # Mark autodetected choice
                     self.source_job.set_label(value, f'{label} (autodetected)')
+                    # Select autodetected choice (i.e. finish job)
+                    self.source_job.choice = value
                     break
 
     @cached_property
@@ -232,12 +237,12 @@ class BhdTrackerJobs(TrackerJobsBase):
         screenshot_groups = as_groups(
             self.upload_screenshots_job.uploaded_images,
             group_sizes=(2, 3),
-            default='MISSING SCREENSHOT',
+            default='PLACEHOLDER',
         )
         for screenshots in screenshot_groups:
             cells = []
             for screenshot in screenshots:
-                if screenshot != 'MISSING SCREENSHOT':
+                if screenshot != 'PLACEHOLDER':
                     cells.append(f'[url={screenshot}][img]{screenshot.thumbnail_url}[/img][/url]')
             # Space between columns
             rows.append(' '.join(cells))
@@ -245,6 +250,58 @@ class BhdTrackerJobs(TrackerJobsBase):
         bbcode = '\n\n'.join(rows)
         return f'[center]\n{bbcode}\n[/center]'
 
+    @cached_property
+    def tags_job(self):
+        job = jobs.dialog.TextFieldJob(
+            name='tags',
+            label='Tags',
+            condition=self.make_job_condition('tags_job'),
+            read_only=True,
+            **self.common_job_args,
+        )
+        job.add_task(
+            job.fetch_text(
+                coro=self.autodetect_tags(),
+                finish_on_success=True,
+            )
+        )
+        return job
+
+    async def autodetect_tags(self):
+        await self.release_name_job.wait()
+        await self.scene_check_job.wait()
+
+        # Any additional tags separated by comma(s). (Commentary, 2in1, Hybrid,
+        # OpenMatte, 2D3D, WEBRip, WEBDL, 3D, 4kRemaster, DualAudio, EnglishDub,
+        # Personal, Scene, DigitalExtras, Extras)
+        tags = []
+        if 'WEBRip' in self.approved_release_name.source:
+            tags.append('WEBRip')
+        elif 'WEB-DL' in self.approved_release_name.source:
+            tags.append('WEBDL')
+        if 'Hybrid' in self.approved_release_name.source:
+            tags.append('Hybrid')
+        if self.approved_release_name.has_commentary:
+            tags.append('Commentary')
+        if self.approved_release_name.has_dual_audio:
+            tags.append('DualAudio')
+        if 'Open Matte' in self.approved_release_name.edition:
+            tags.append('OpenMatte')
+        if self.get_job_attribute(self.scene_check_job, 'is_scene_release'):
+            tags.append('Scene')
+        if self.options['personal_rip']:
+            tags.append('Personal')
+
+        # TODO: 4kRemaster (waiting for https://github.com/guessit-io/guessit/pull/701)
+        # TODO: 2in1 (waiting for https://github.com/guessit-io/guessit/pull/702)
+        # TODO: 2D3D
+        # TODO: 3D
+        # TODO: EnglishDub
+        # TODO: DigitalExtras
+        # TODO: Extras
+
+        return '\n'.join(tags)
+
     @property
     def submission_ok(self):
         """
@@ -268,7 +325,7 @@ class BhdTrackerJobs(TrackerJobsBase):
             'description': self.get_job_output(self.description_job, slice=0),
             'edition': self.post_data_edition,
             'custom_edition': self.options['custom_edition'],
-            'tags': self.post_data_tags,
+            'tags': ','.join(self.get_job_output(self.tags_job, slice=0).split('\n')),
             'nfo': self.post_data_nfo,
             'pack': self.post_data_pack,
             'sd': self.post_data_sd,
@@ -320,39 +377,6 @@ class BhdTrackerJobs(TrackerJobsBase):
         else:
             return '1' if height < 720 else '0'
 
-    @property
-    def post_data_tags(self):
-        # Any additional tags separated by comma(s). (Commentary, 2in1, Hybrid,
-        # OpenMatte, 2D3D, WEBRip, WEBDL, 3D, 4kRemaster, DualAudio, EnglishDub,
-        # Personal, Scene, DigitalExtras, Extras)
-        tags = []
-        if 'WEBRip' in self.approved_release_name.source:
-            tags.append('WEBRip')
-        elif 'WEB-DL' in self.approved_release_name.source:
-            tags.append('WEBDL')
-        if 'Hybrid' in self.approved_release_name.source:
-            tags.append('Hybrid')
-        if self.approved_release_name.has_commentary:
-            tags.append('Commentary')
-        if self.approved_release_name.has_dual_audio:
-            tags.append('DualAudio')
-        if 'Open Matte' in self.approved_release_name.edition:
-            tags.append('OpenMatte')
-        if self.get_job_attribute(self.scene_check_job, 'is_scene_release'):
-            tags.append('Scene')
-        if self.options['personal_rip']:
-            tags.append('Personal')
-
-        # TODO: 4kRemaster (waiting for https://github.com/guessit-io/guessit/pull/701)
-        # TODO: 2in1 (waiting for https://github.com/guessit-io/guessit/pull/702)
-        # TODO: 2D3D
-        # TODO: 3D
-        # TODO: EnglishDub
-        # TODO: DigitalExtras
-        # TODO: Extras
-
-        return ','.join(tags)
-
     max_nfo_size = 500_000
 
     @property
