@@ -1,9 +1,6 @@
 from ....utils import cached_property
 from . import JobWidgetBase
 
-import logging  # isort:skip
-_log = logging.getLogger(__name__)
-
 
 # This job is hidden so we only need a dummy widget.
 
