@@ -7,8 +7,8 @@ import os
 import re
 import time
 
-from .. import constants, errors
-from . import LazyModule, os_family, string
+from .. import __project_name__, constants, errors
+from . import LazyModule, os_family, types
 
 import logging  # isort:skip
 _log = logging.getLogger(__name__)
@@ -55,7 +55,7 @@ def projectdir(content_path, base=None):
     if content_path:
         if not base:
             base = constants.CACHE_DIRPATH
-        path = os.path.join(base, basename(content_path) + '.upsies')
+        path = os.path.join(base, basename(content_path) + f'.{__project_name__}')
     else:
         path = '.'
     if not os.path.exists(path):
@@ -78,7 +78,7 @@ def limit_directory_size(path, max_total_size, min_age=None, max_age=None):
     :param max_age: Preserve files that are older than this
     :type max_age: int or float
     """
-    def size(filepaths):
+    def combined_size(filepaths):
         return sum(file_size(f) for f in filepaths
                    if os.path.exists(f) and not os.path.islink(f))
 
@@ -87,9 +87,12 @@ def limit_directory_size(path, max_total_size, min_age=None, max_age=None):
         statinfo = os.stat(filepath, follow_symlinks=False)
         return statinfo.st_atime
 
-    # Remove oldest file until `path` size is small enough
-    filepaths = file_list(path, min_age=min_age, max_age=max_age)
-    while size(filepaths) > max_total_size:
+    def get_filepaths(dirpath):
+        return file_list(dirpath, min_age=min_age, max_age=max_age, follow_dirlinks=False)
+
+    # Keep removing oldest file until `path` size is small enough
+    filepaths = get_filepaths(path)
+    while combined_size(filepaths) > max_total_size:
         oldest_file = sorted(filepaths, key=atime)[0]
         try:
             os.unlink(oldest_file)
@@ -99,7 +102,7 @@ def limit_directory_size(path, max_total_size, min_age=None, max_age=None):
             else:
                 raise RuntimeError(f'{oldest_file}: Failed to prune: {e}')
         else:
-            filepaths = file_list(path, min_age=min_age, max_age=max_age)
+            filepaths = get_filepaths(path)
 
     prune_empty(path, files=True, directories=True)
 
@@ -127,7 +130,7 @@ def prune_empty(path, files=False, directories=True):
 
     # Prune empty files
     if files:
-        for dirpath, dirnames, filenames in os.walk(path, topdown=False):
+        for dirpath, dirnames, filenames in os.walk(path, topdown=False, followlinks=False):
             for filename in filenames:
                 filepath = os.path.join(dirpath, filename)
                 try:
@@ -138,7 +141,7 @@ def prune_empty(path, files=False, directories=True):
 
     # Prune empty directories
     if directories:
-        for dirpath, dirnames, filenames in os.walk(path, topdown=False):
+        for dirpath, dirnames, filenames in os.walk(path, topdown=False, followlinks=False):
             for dirname in dirnames:
                 subdirpath = os.path.join(dirpath, dirname)
                 try:
@@ -148,7 +151,7 @@ def prune_empty(path, files=False, directories=True):
                     raise_error(e, subdirpath)
 
     # Prune dead links
-    for dirpath, dirnames, filenames in os.walk(path, topdown=False):
+    for dirpath, dirnames, filenames in os.walk(path, topdown=False, followlinks=False):
         for filename in filenames:
             filepath = os.path.join(dirpath, filename)
             try:
@@ -230,11 +233,13 @@ def sanitize_filename(filename):
     Replace illegal characters in `filename` with "_"
     """
     if os_family() == 'windows':
-        for char in ('<', '>', ':', '"', '/', '\\', '|', '?', '*'):
-            filename = filename.replace(char, '_')
-        return filename
+        illegal_chars = ('<', '>', ':', '"', '/', '\\', '|', '?', '*')
     else:
-        return filename.replace('/', '_')
+        illegal_chars = ('/',)
+
+    for char in illegal_chars:
+        filename = filename.replace(char, '_')
+    return filename
 
 
 def file_extension(path):
@@ -295,7 +300,7 @@ def file_size(path):
     return None
 
 
-def file_list(path, extensions=(), min_age=None, max_age=None):
+def file_list(path, extensions=(), min_age=None, max_age=None, follow_dirlinks=False):
     """
     List naturally sorted files in `path` and any subdirectories
 
@@ -310,6 +315,8 @@ def file_list(path, extensions=(), min_age=None, max_age=None):
     :type min_age: int or float
     :param max_age: Exclude files that are older than this
     :type max_age: int or float
+    :param follow_dirlinks: Whether to include the contents of symbolic links to
+        directories or the links themselves
 
     :return: Tuple of file paths
     """
@@ -330,11 +337,28 @@ def file_list(path, extensions=(), min_age=None, max_age=None):
             return ()
 
     files = []
-    for root, dirnames, filenames in os.walk(path):
+    for root, dirnames, filenames in os.walk(path, topdown=True, followlinks=follow_dirlinks):
         for filename in sorted(filenames):
             filepath = os.path.join(root, filename)
             if ext_ok(filename) and age_ok(filepath):
                 files.append(filepath)
+
+        # Symbolic links to directories are in `dirnames`
+        if not follow_dirlinks:
+            # For symbolic links that point to a directory, os.walk() can only
+            # include the contents (followlinks=True) or completely ignore the
+            # link. Here we look for links to directories and a) include them in
+            # the returned list and b), remove them from `dirnames` so os.walk()
+            # doesn't recurse into them. It is important to pass topdown=True
+            # for b) to work.
+            for dirname in tuple(dirnames):
+                # Contrary to what the docs say, this returns `True` for dead
+                # and living symbolic links
+                dirpath = os.path.join(root, dirname)
+                if os.path.islink(dirpath):
+                    del dirnames[dirnames.index(dirname)]
+                    files.append(dirpath)
+
     return tuple(natsort.natsorted(files, key=str.casefold))
 
 
@@ -382,9 +406,19 @@ def file_tree(tree, _parents_is_last=()):
                 indent += f'{_DOWN_RIGHT}{_RIGHT}'
 
         if isinstance(node, int):
-            lines.append(f'{indent}{name} ({string.pretty_bytes(node)})')
+            lines.append(f'{indent}{name} ({types.Bytes(node)})')
         else:
-            lines.append(f'{indent}{name}')
+            def sum_node_size(nodelist):
+                size = 0
+                for node in nodelist:
+                    if isinstance(node, tuple):
+                        if len(node) >= 2 and isinstance(node[1], int):
+                            size += node[1]
+                        else:
+                            size += sum_node_size(node)
+                return size
+
+            lines.append(f'{indent}{name} ({types.Bytes(sum_node_size(node))})')
             # Descend into child node
             sub_parents_is_last = _parents_is_last + (is_last,)
             lines.append(file_tree(node, _parents_is_last=sub_parents_is_last))
