@@ -10,7 +10,6 @@ adds a :class:`~.ReleaseName.format` method to turn everything back into a
 string.
 """
 
-import asyncio
 import collections
 import os
 import re
@@ -449,13 +448,12 @@ class ReleaseName(collections.abc.Mapping):
 
           - :attr:`title`
           - :attr:`title_aka`
+          - :attr:`type`
           - :attr:`year`
           - :attr:`year_required`
         """
-        await asyncio.gather(
-            self._update_attributes(id),
-            self._update_year_required(),
-        )
+        await self._update_attributes(id)
+        await self._update_year_required()
         _log.debug('Release name updated: %s', self)
         if callback is not None:
             callback(self)
@@ -469,9 +467,9 @@ class ReleaseName(collections.abc.Mapping):
             'year',
         )
         for attr, key in (
-                ('title', 'title_original'),
-                ('title_aka', 'title_english'),
-                ('year', 'year')
+            ('title', 'title_original'),
+            ('title_aka', 'title_english'),
+            ('year', 'year'),
         ):
             # Only overload non-empty values
             if info[key]:
